from .device import Device
from .trip import Trip
from .authentication import Authentication
import requests

class API:

    def __init__(self, client_id, client_secret, username, password):
        self._client_id = client_id
        self._client_secret = client_secret
        self._username = username
        self._password = password
        self.authentication_info = None

    def logged_in(self):
        if (self.authentication_info is None):
            return False
        else:
            return self.authentication_info.is_valid()

    def login(self):
        import requests

        data_url = "https://api.ritassist.nl/api/session/login"

        body = {
            'client_id': self._client_id,
            'client_secret': self._client_secret,
            'username': self._username,
            'password': self._password
        }

        response = requests.post(data_url, json=body)

        self.authentication_info = Authentication()
        self.authentication_info.set_json(response.json())
        return self.logged_in()

    def get_devices(self):
        if (self.authentication_info is None or
            not self.authentication_info.is_valid()):
            return []

        data_url = "https://api.ritassist.nl/api/equipment/Getfleet"
        query = "?groupId=0&hasDeviceOnly=false"

        header = self.authentication_info.create_header()
        response = requests.get(data_url + query, headers=header)
        data = response.json()
        return self.parse_devices(data)

    def parse_devices(self, json):
        """Parse result from API."""
        result = []

        for json_device in json:
            license_plate = json_device['EquipmentHeader']['SerialNumber']

            device = Device(self, license_plate)
            device.update_from_json(json_device)
            result.append(device)

        return result


from .address import Address

class TripDetail:
    def __init__(self, json):
        self.date = None
        self.odometer = 0
        self.description = None
        self.address = None
        self.latitude = 0
        self.longitude = 0
        self.altitude = 0
        self.minutes_on_location = 0
        self.parse_json(json)
    
    def parse_json(self, json):
        import ciso8601

        self.odometer = json['Odometer']
        self.description = json['Description']
        self.latitude = json['Location']['Latitude']
        self.longitude = json['Location']['Longitude']
        self.altitude = json['Location']['Altitude']
        self.minutes_on_location = json['MinutesAtLocation']

        if json['DateTime'] is not None:
            self.date = ciso8601.parse_datetime(json['DateTime'])
        else:
            self.date = None

        self.address = Address(json['Address'])

    def __str__(self):
        return f"{self.address}"